pub fn engine_block(engine: &EngineProvenance) -> ValueExpand description
The complete engine block: contract, version, digest, provenance, policy version, and the three adapter descriptors with their digests.
pub fn engine_block(engine: &EngineProvenance) -> ValueThe complete engine block: contract, version, digest, provenance, policy version, and the three adapter descriptors with their digests.