pub struct ErrorDetail {
pub code: AnalysisErrorCode,
pub path: Option<String>,
pub resource: Option<(ResourceName, u64, u64)>,
}Expand description
One typed analysis error’s reportable detail: the code, the exact path where the partition names one, and the crossing triple for a resource error.
Fields
code: AnalysisErrorCodepath: Option<String>resource: Option<(ResourceName, u64, u64)>Implementations