pub enum BlobMode {
Regular,
Executable,
}Expand description
The two ordinary Git blob modes. Trees, symlinks, and gitlinks are represented by other target types and cannot be smuggled into a blob.
Variants