VersionScope

Enum VersionScope 

pub enum VersionScope<P> {
    KnownPath {
        path: P,
    },
    UnknownPath,
}
Version-scoped forge references either identify a contained path outside the candidate scope or fail before a path can be identified.

Variants



KnownPath

Fields

path: P


UnknownPath