pub enum VersionScope<P> {
KnownPath {
path: P,
},
UnknownPath,
}Expand description
Version-scoped forge references either identify a contained path outside the candidate scope or fail before a path can be identified.
Variants